import mimetypes
import nautilus
import os
import urllib


FORMATS = ["video/x-flv", "video/mpeg", "video/x-mpeg", "video/quicktime",
           "video/x-quicktime", "video/msvideo", "video/x-msvideo",
           "video/x-ms-asf-plugin", "video/divx", "video/vnd.divx",
           "video/vnd.rn-realvideo", "video/x-ms-asf", "video/x-ms-wm",
           "video/x-ms-wmv", "video/x-ms-wmp", "video/x-ms-wvx", "video/x-mpeg2",
           "video/mp4", "video/3gpp", "video/fli", "video/x-fli", "video/vnd.vivo",
           "application/x-flash-video"]


def process(dir_name, supported):
    """If it's a supported file, normalize its name and add it to the list.
    If it's a directory, add recursively all its supported files."""
    content = os.listdir(dir_name)
    for file_name in content:
        path = os.path.join(dir_name, file_name)
        if mimetypes.guess_type(path)[0] in FORMATS:
            supported.append(normalize(path))
        elif os.path.isdir(path):
            supported = process(path, supported)

    return supported


def normalize(path):
    path = path.replace(" ", "\\ ")
    path = path.replace("(", "\\(")
    path = path.replace(")", "\\)")
    path = path.replace("'", "\\'")
    path = path.replace("&", "\\&")
    return path


class PlayMplayerExtension(nautilus.MenuProvider):
    def __init__(self):
        self.file_names = []


    def menu_activate_cb(self, menu, names):
        """Called when the user selects the menu. Launch mplayer with the
        files selected."""
        self.queue = ""
        sorted = names
        sorted.sort()
        for name in sorted:
            self.queue = ("%s %s") % (self.queue, name)
        os.system("mplayer %s &" % self.queue)


    def get_file_items(self, window, files):
        """Called when the user selects a file in Nautilus. We want to check
        whether those are supported files or directories with supported files."""
        supported = []
        for f in files:
            if f.get_mime_type() in FORMATS:
                name = urllib.unquote(f.get_uri()[7:])
                supported.append(normalize(name))
            elif f.is_directory():
                supported = process(urllib.unquote(f.get_uri()[7:]), supported)


        if not supported:
            return


        item = nautilus.MenuItem("NautilusPython::play_mplayer_item",
                                 "Play with MPlayer" ,
                                 "Play with Mplayer",
                                 "nautilus-play-mplayer")
        item.connect("activate", self.menu_activate_cb, supported)
        return item,



